*****************************************************************************************
*                                                                                       *
*  DragonsLair2.Bitmap.s :  Library for Bitmap Handling (Numbers + Character Set).      *
*                                                                                       *
*****************************************************************************************
*  Authors : Antoine VIGNAU / Olivier ZARDINI  *  Brutal Deluxe Software  *   Dec 2021  *
*****************************************************************************************

*----------   Merlin 16+ Directives   ---------

                    mx         %00                  ; Assemble in 16 bit

                    rel                             ; Build a relocated S16 file
                    dsk        Bitmap.l             ; Name of the Segment
                    
***********************************************************
*  EntryPointBitmap() :  Entry Point of Segment 'Bitmap'. *
***********************************************************
EntryPointBitmap    ENT                             ; First Byte of this Segment
                    RTL
                    
                    
******************************************************************************************
*  CopyOneBitmap() :  Copy one Bitmap to Screen (IN:A=Width4|Heigh,IN:X=@Src,IN:Y=@Dst). *
******************************************************************************************
CopyOneBitmap       ENT
                    PHB
                    PHK                             ; Current Bank = Data Bank
                    PLB
*--
                    STX        COB_Data+1           ; X = Src @
                    STY        COB_Screen+1         ; Y = Dst @
                    TAX                             ; A = Width4/Heigh
                    AND        #$00FF               ; Heigh
                    STA        COB_Heigh+1
                    TXA
                    XBA
                    AND        #$00FF               ; Width4
                    STA        COB_Width+1
                    LDA        #$00A0
                    SEC
                    SBC        COB_Width+1
                    SEC
                    SBC        COB_Width+1
                    STA        COB_Offset+1
*--                                                    
                    LDY        #$0000               ; Copy Bitmap Data
                    LDX        #$0000
COB_Data            LDA        $AAAA                ; Number Pixel
COB_Screen          STAL       $012000              ; Screen Address
                    INC        COB_Data+1
                    INC        COB_Data+1
                    INC        COB_Screen+1
                    INC        COB_Screen+1                    
                    INX
COB_Width           CPX        #$AAAA
                    BNE        COB_Data
                    LDA        COB_Screen+1
                    CLC
COB_Offset          ADC        #$00A0               ; #$A0 - Width
                    STA        COB_Screen+1
                    LDX        #$0000
                    INY
COB_Heigh           CPY        #$AAAA
                    BNE        COB_Data
*--
                    PLB
                    RTL


***************************************************************************************************************************
*  CopyTransBitmap() :  Copy one Transparent Bitmap to Screen (IN:A=Width4|Heigh,IN:X=@Src,IN:Y=@Dst,IN:Carry=0/1:01:E1). *
***************************************************************************************************************************
CopyTransBitmap     ENT
                    PHB
                    PHK                             ; Current Bank = Data Bank
                    PLB
*--
                    PHA
                    BCC        CTB_01               ; Target Screen is 01/ or E1/
CTB_E1              LDA        #$E120
                    BRA        CTB_Screen
CTB_01              LDA        #$0120
CTB_Screen          STA        CTB_Screen_1+2
                    STA        CTB_Screen_2+2
                    PLA
*--
                    STX        CTB_Data+1           ; X = Src @
                    STY        CTB_Screen_1+1       ; Y = Dst @
                    STY        CTB_Screen_2+1
                    TAX                             ; A = Width4/Heigh
                    AND        #$00FF               ; Heigh
                    STA        CTB_Heigh+1
                    TXA
                    XBA
                    AND        #$00FF               ; Width4
                    STA        CTB_Width+1
                    LDA        #$00A0
                    SEC
                    SBC        CTB_Width+1
                    SEC
                    SBC        CTB_Width+1
                    STA        CTB_Offset+1
*--                                                    
                    LDY        #$0000               ; Copy Transparent Bitmap
                    LDX        #$0000
CTB_Data            LDA        $AAAA                ; Bitmap Data
                    STA        CTB_DataBitmap
*--
CTB_Mask_1          LDA        #$FFFF               ; Prepare Mask
                    STA        CTB_MaskBitmap
                    LDA        CTB_DataBitmap
                    AND        #$000F
                    BEQ        CTB_Mask_2
                    LDA        CTB_MaskBitmap
                    AND        #$FFF0
                    STA        CTB_MaskBitmap
CTB_Mask_2          LDA        CTB_DataBitmap
                    AND        #$00F0
                    BEQ        CTB_Mask_3
                    LDA        CTB_MaskBitmap
                    AND        #$FF0F
                    STA        CTB_MaskBitmap
CTB_Mask_3          LDA        CTB_DataBitmap
                    AND        #$0F00
                    BEQ        CTB_Mask_4
                    LDA        CTB_MaskBitmap
                    AND        #$F0FF
                    STA        CTB_MaskBitmap
CTB_Mask_4          LDA        CTB_DataBitmap
                    AND        #$F000
                    BEQ        CTB_Screen_1
                    LDA        CTB_MaskBitmap
                    AND        #$0FFF
                    STA        CTB_MaskBitmap                                                              
*--
CTB_Screen_1        LDAL       $012000              ; Background Data
                    AND        CTB_MaskBitmap       ; AND Mask
                    ORA        CTB_DataBitmap       ; ORA Data             
CTB_Screen_2        STAL       $012000
*--
                    INC        CTB_Data+1
                    INC        CTB_Data+1
                    INC        CTB_Screen_1+1
                    INC        CTB_Screen_1+1
                    INC        CTB_Screen_2+1
                    INC        CTB_Screen_2+1
                    INX
CTB_Width           CPX        #$AAAA
                    BNE        CTB_Data
                    LDA        CTB_Screen_1+1
                    CLC
CTB_Offset          ADC        #$00A0               ; #$A0 - Width
                    STA        CTB_Screen_1+1
                    STA        CTB_Screen_2+1
                    LDX        #$0000
                    INY
CTB_Heigh           CPY        #$AAAA
                    BEQ        CTB_End
                    JMP        CTB_Data
*--
CTB_End             PLB
                    RTL

*----------   CopyTransBitmap Variables   ---------
CTB_MaskBitmap      HEX        0000                 ; Mask 0-F
CTB_DataBitmap      HEX        0000                 ; Data 


********************************************************************************************
*  RemapBitmapColor() :  Remap Bitmap Color (IN:A=ColorSrcColorDst,IN:X=@Src,IN:Y=Length). *
********************************************************************************************
RemapBitmapColor    ENT
                    PHB
                    PHK                             ; Current Bank = Data Bank
                    PLB
*--
                    STX        RBC_Data_1+1         ; @Data
                    STX        RBC_Data_4+1
                    STY        RBC_Length+1         ; Data Length
                    SEP        #$20
                    PHA                             ; Color Dst
                    AND        #$0F
                    STA        RBC_ColorDst1
                    PLA 
                    AND        #$F0
                    STA        RBC_ColorDst2
                    XBA
                    PHA                             ; Color Src
                    AND        #$0F
                    STA        RBC_ColorSrc1
                    PLA 
                    AND        #$F0
                    STA        RBC_ColorSrc2
*--                    
                    LDX        #$0000
RBC_Data_1          LDA        $AAAA,X
                    STA        RBC_Data
                    AND        #$0F                 ; Color 0c
                    CMP        RBC_ColorSrc1
                    BNE        RBC_Data_2
                    LDA        RBC_Data
                    AND        #$F0
                    ORA        RBC_ColorDst1
                    STA        RBC_Data
*--                   
RBC_Data_2          LDA        RBC_Data             ; Color c0
                    AND        #$F0
                    CMP        RBC_ColorSrc2
                    BNE        RBC_Data_3
                    LDA        RBC_Data
                    AND        #$0F
                    ORA        RBC_ColorDst2
                    STA        RBC_Data
*--
RBC_Data_3          LDA        RBC_Data
RBC_Data_4          STA        $AAAA,X
                    INX
RBC_Length          CPX        #$AAAA
                    BNE        RBC_Data_1                    
*--
                    REP        #$30
                    PLB
                    RTL

*----------   RemapBitmapColor Variables   ---------
RBC_Data            HEX        00
RBC_ColorSrc1       HEX        00                   ; 0s
RBC_ColorSrc2       HEX        00                   ; s0
RBC_ColorDst1       HEX        00                   ; 0d
RBC_ColorDst2       HEX        00                   ; d0


************************************************************************************
*  DisplayHintBitmap() :  Remap & Display Hint Bitmap (IN:A=SceneID,IN:X=@Bitmap). *
************************************************************************************
DisplayHintBitmap   ENT
                    PHB
                    PHK
                    PLB
*--
                    LDY       #$220D                ; @ Screen
                    JSR       DisplayRemapBitmap
*--
                    PLB
                    RTL


************************************************************************************
*  DisplayDiskBitmap() :  Remap & Display Disk Bitmap (IN:A=SceneID,IN:X=@Bitmap). *
************************************************************************************
DisplayDiskBitmap   ENT
                    PHB
                    PHK
                    PLB
*--
                    LDY       #$01E1                ; @ Screen
                    JSR       DisplayRemapBitmap
*--
                    PLB
                    RTL


********************************************************************************************************
*  DisplayRemapBitmap() :  Remap & Display Bitmap on Screen (IN:A=SceneID,IN:X=@Bitmap,IN:Y=@Screen). *
********************************************************************************************************
DisplayRemapBitmap  STY        DRB_ScreenAddress+1  ; @ Screen
                    STA        DRB_SceneID+1        ; Scene ID
                    STX        DRB_ColorRemap+1     ; @ Bitmap
                    TXA                             ; @ Mask
                    CLC
                    ADC        #$0048
                    STA        DRB_Mask_0+1
                    INC
                    INC
                    STA        DRB_Mask_1+1
                    INC
                    INC
                    STA        DRB_Mask_2+1
*----
                    LDX        #$0000               ; Remap Color Scheme
DRB_ColorScheme     LDA        ColorSceneTab,X
DRB_SceneID         CMP        #$AAAA               ; Scene ID
                    BEQ        DRB_ColorSet
                    INX
                    INX
                    BRA        DRB_ColorScheme
DRB_ColorSet        LDA        ColorBWTab,X         ; Black White
*--
                    SEP        #$20
                    PHA                             ; New White
                    AND        #$F0
                    STA        DRB_RemapWhite_1+1
                    PLA
                    AND        #$0F
                    STA        DRB_RemapWhite_2+1
                    XBA
                    PHA                             ; New Black
                    AND        #$F0
                    STA        DRB_RemapBlack_1+1
                    PLA
                    AND        #$0F
                    STA        DRB_RemapBlack_2+1
*--                                        
                    LDX        #$0047
DRB_ColorRemap      LDA        $AAAA,X              ; Bitmap
                    STA        DRB_ColorRemap_2+1
*--                    
DRB_ColorRemap_1    AND        #$F0                 ; Remap Color #1
                    CMP        #$10                 ; 1 = White
                    BEQ        DRB_RemapWhite_1
                    CMP        #$20                 ; 2 = Black
                    BEQ        DRB_RemapBlack_1
                    BRA        DRB_ColorRemap_10
DRB_RemapWhite_1    LDA        #$C0                 ; New White
                    BRA        DRB_ColorRemap_10
DRB_RemapBlack_1    LDA        #$C0                 ; New Black
DRB_ColorRemap_10   STA        DRB_Color_1+1
*--
DRB_ColorRemap_2    LDA        #$AA                 ; Remap Color #2
                    AND        #$0F
                    CMP        #$01                 ; 1 = White
                    BEQ        DRB_RemapWhite_2
                    CMP        #$02                 ; 2 = Black
                    BEQ        DRB_RemapBlack_2
                    BRA        DRB_ColorRemap_20
DRB_RemapWhite_2    LDA        #$0C                 ; New White
                    BRA        DRB_ColorRemap_20
DRB_RemapBlack_2    LDA        #$0C                 ; New Black
DRB_ColorRemap_20   STA        DRB_Color_2+1    
*--
DRB_Color_1         LDA        #$C0
DRB_Color_2         ORA        #$0C
                    STA        DRB_Buffer,X         ; Remap Buffer
                    DEX
                    BPL        DRB_ColorRemap   
                    REP        #$30
*----
DRB_ScreenAddress   LDX        #$AAAA               ; Screen Address
                    LDY        #$0000               ; 12 lines * 6 pixels
*--
DRB_Display         LDAL       $E12000,X            ; Background
DRB_Mask_0          AND        Aplha_Event_Mask+0,Y ; Mask
                    ORA        DRB_Buffer+0,Y       ; Data
                    STAL       $E12000,X            ; Background
                    LDAL       $E12002,X            ; Background
DRB_Mask_1          AND        Aplha_Event_Mask+2,Y ; Mask
                    ORA        DRB_Buffer+2,Y       ; Data
                    STAL       $E12002,X            ; Background
                    LDAL       $E12004,X            ; Background
DRB_Mask_2          AND        Aplha_Event_Mask+4,Y ; Mask
                    ORA        DRB_Buffer+4,Y       ; Data
                    STAL       $E12004,X            ; Background
*--
                    TXA                             ; Next Screen Line
                    CLC
                    ADC        #$00A0
                    TAX
                    TYA                             ; Next Bitmap Line
                    CLC
                    ADC        #$0006
                    TAY
                    CPY        #$0048
                    BNE        DRB_Display
*----
                    RTS

*----------   DisplayRemapBitmap Variables   ---------
DRB_Buffer          HEX        00,00,00,00,00,00    ; Buffer for Color Remap
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00


************************************
*  Disk Screen 1-8 Numbers Pixels  *
************************************

DiskTable           ENT
                    DA         Disk1,Disk2,Disk3,Disk4,Disk5,Disk6,Disk7,Disk8
                                  
Disk1               HEX        12,02,7061           ; 1 : Height, Width4, Screen @
                    HEX        15,15,44,15
                    HEX        51,55,44,55
                    HEX        15,54,44,51
                    HEX        44,44,44,55
                    HEX        44,44,44,51
                    HEX        51,55,44,55
                    HEX        15,55,44,51
                    HEX        51,51,44,55
                    HEX        55,15,44,55
                    HEX        15,55,44,51
                    HEX        55,15,44,55
                    HEX        15,55,44,55
                    HEX        55,15,44,55
                    HEX        55,55,44,55
                    HEX        15,55,44,15
                    HEX        55,55,44,55
                    HEX        15,51,44,55
                    HEX        55,55,44,51
                          
Disk2               HEX        12,03,6F61           ; 2 : Height, Width4, Screen @               
                    HEX        15,15,64,44,65,55
                    HEX        55,54,44,44,44,55
                    HEX        15,44,61,55,64,45
                    HEX        56,46,15,51,56,46
                    HEX        14,45,51,55,51,44
                    HEX        54,41,55,55,55,44
                    HEX        55,15,55,51,51,44
                    HEX        51,51,51,55,54,46
                    HEX        15,55,15,15,44,45
                    HEX        55,15,55,64,44,55
                    HEX        55,55,14,44,45,55
                    HEX        15,15,44,44,55,55
                    HEX        51,54,44,65,55,55
                    HEX        15,44,45,55,55,55
                    HEX        54,44,55,55,15,55
                    HEX        64,46,55,55,55,55
                    HEX        44,44,44,44,44,44
                    HEX        44,44,44,44,44,44

Disk3               HEX        12,03,6F61           ; 3 : Height, Width4, Screen @
                    HEX        15,16,44,44,65,55
                    HEX        55,44,44,44,44,55
                    HEX        16,46,51,55,64,65
                    HEX        54,45,15,51,54,41
                    HEX        14,45,51,55,54,45
                    HEX        54,41,55,55,54,45
                    HEX        55,15,55,51,54,45
                    HEX        51,51,51,55,44,61
                    HEX        15,55,14,44,46,55
                    HEX        55,15,54,44,44,65
                    HEX        55,55,15,15,64,46
                    HEX        15,15,55,55,55,44
                    HEX        51,55,15,55,55,44
                    HEX        14,45,55,55,55,44
                    HEX        54,45,55,55,16,44
                    HEX        56,44,55,55,64,46
                    HEX        55,44,44,44,44,65
                    HEX        15,56,44,44,46,55
                      
Disk4               HEX        12,03,6F61           ; 4 : Height, Width4, Screen @
                    HEX        15,15,15,54,45,55
                    HEX        55,51,55,64,45,55
                    HEX        15,15,51,44,41,55
                    HEX        51,55,14,44,45,51
                    HEX        15,15,64,44,41,55
                    HEX        51,51,44,54,45,55
                    HEX        55,14,45,54,41,55
                    HEX        51,64,61,54,45,51
                    HEX        15,44,15,14,45,55
                    HEX        54,45,55,54,41,55
                    HEX        64,65,15,14,45,55
                    HEX        44,15,55,54,45,55
                    HEX        44,44,44,44,44,45
                    HEX        44,44,44,44,44,45
                    HEX        55,15,55,54,45,55
                    HEX        55,55,55,54,45,55
                    HEX        55,15,51,54,45,55
                    HEX        15,55,55,54,41,55
                                             
Disk5               HEX        12,03,6F61           ; 5 : Height, Width4, Screen @
                    HEX        14,44,44,44,44,44
                    HEX        54,44,44,44,44,44
                    HEX        14,45,51,55,51,55
                    HEX        54,45,15,51,55,51
                    HEX        14,45,51,55,51,55
                    HEX        54,41,55,55,55,55
                    HEX        54,44,44,44,61,55
                    HEX        54,44,44,44,44,51
                    HEX        15,55,15,15,44,45
                    HEX        55,15,55,55,54,46
                    HEX        55,55,15,15,55,44
                    HEX        15,15,55,55,55,44
                    HEX        54,45,15,55,55,44
                    HEX        14,45,55,55,55,44
                    HEX        56,46,55,55,16,46
                    HEX        55,44,65,55,64,45
                    HEX        55,14,44,44,44,55
                    HEX        15,55,64,44,61,55
                                                    
Disk6               HEX        12,03,7061           ; 6 : Height, Width4, Screen @
                    HEX        15,16,44,46,55,15
                    HEX        51,44,44,44,45,55
                    HEX        14,46,55,56,44,15
                    HEX        64,65,51,55,64,65
                    HEX        44,61,55,51,55,51
                    HEX        44,55,55,55,55,55
                    HEX        44,55,51,51,55,55
                    HEX        44,56,44,46,51,55
                    HEX        44,64,44,44,45,55
                    HEX        44,44,65,54,44,55
                    HEX        44,45,15,55,44,61
                    HEX        44,65,55,55,54,45
                    HEX        44,15,55,55,54,45
                    HEX        44,55,55,55,54,45
                    HEX        64,65,55,15,64,65
                    HEX        54,46,55,56,44,55
                    HEX        15,44,44,44,45,55
                    HEX        55,56,44,46,55,55

Disk7               HEX        12,03,6F61           ; 7 : Height, Width4, Screen @
                    HEX        44,44,44,44,44,44
                    HEX        44,44,44,44,44,44
                    HEX        15,15,51,55,56,44
                    HEX        51,55,15,51,54,46
                    HEX        15,15,51,55,64,45
                    HEX        51,51,55,55,44,65
                    HEX        55,15,55,56,44,55
                    HEX        51,51,51,54,46,51
                    HEX        15,55,15,64,45,55
                    HEX        55,15,55,44,61,55
                    HEX        55,55,16,44,55,55
                    HEX        15,15,54,46,55,55
                    HEX        51,55,64,45,55,55
                    HEX        15,55,44,65,55,55
                    HEX        55,16,44,55,15,55
                    HEX        55,54,46,55,55,55
                    HEX        55,64,41,55,55,55
                    HEX        15,44,65,55,51,55

Disk8               HEX        12,03,6F61           ; 8 : Height, Width4, Screen @
                    HEX        15,16,44,44,46,55
                    HEX        55,64,44,44,44,45
                    HEX        16,44,61,55,64,46
                    HEX        54,46,15,51,56,44
                    HEX        14,45,51,55,51,44
                    HEX        54,41,55,55,55,44
                    HEX        54,45,55,51,51,44
                    HEX        56,44,61,55,64,46
                    HEX        15,54,44,44,44,55
                    HEX        55,64,44,44,44,65
                    HEX        56,44,65,15,64,46
                    HEX        14,45,55,55,55,44
                    HEX        54,45,15,55,55,44
                    HEX        14,45,55,55,55,44
                    HEX        54,46,55,55,16,44
                    HEX        56,44,65,55,64,46
                    HEX        55,64,44,44,44,45
                    HEX        15,56,44,44,46,55


*****************************************
*  Score/Life Screen 0-9 Number Pixels  *
*****************************************

NumberTable         ENT
                    DA         Number0,Number1,Number2,Number3,Number4,Number5,Number6,Number7,Number8,Number9

Number0             HEX        00,00,00,77,70,00,00,00 ; 0
                    HEX        00,00,77,11,17,70,00,00
                    HEX        00,07,11,11,11,17,00,00
                    HEX        00,71,11,77,71,11,70,00
                    HEX        00,71,17,70,77,11,70,00
                    HEX        07,11,17,00,07,11,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,70,00,00,71,17,00
                    HEX        07,11,17,00,07,11,17,00
                    HEX        07,71,17,70,77,11,77,00
                    HEX        00,71,11,77,71,11,70,00
                    HEX        00,77,11,11,11,17,70,00
                    HEX        00,07,77,11,17,77,00,00
                    HEX        00,00,07,77,77,00,00,00

Number1             HEX        00,00,00,00,77,70,00,00 ; 1
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,71,11,70,00,00
                    HEX        00,00,07,11,11,70,00,00
                    HEX        00,00,71,11,11,70,00,00
                    HEX        00,00,71,17,11,70,00,00
                    HEX        00,00,77,77,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,11,70,00,00
                    HEX        00,00,00,07,77,70,00,00

Number2             HEX        00,00,00,77,77,70,00,00 ; 2
                    HEX        00,00,77,11,11,17,70,00
                    HEX        00,07,11,11,11,11,17,00
                    HEX        00,71,11,77,77,71,11,70
                    HEX        00,71,17,70,00,77,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,77,77,00,00,07,11,70
                    HEX        00,00,00,00,00,71,11,70
                    HEX        00,00,00,00,07,11,17,70
                    HEX        00,00,00,00,71,11,77,00
                    HEX        00,00,00,07,11,17,70,00
                    HEX        00,00,00,71,11,77,00,00
                    HEX        00,00,07,11,17,70,00,00
                    HEX        00,00,71,11,77,00,00,00
                    HEX        00,07,11,17,70,00,00,00
                    HEX        00,71,11,77,77,77,77,70
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,77,77,77,77,77,77,70

Number3             HEX        00,00,00,77,77,00,00,00 ; 3
                    HEX        00,00,77,11,11,77,00,00
                    HEX        00,07,11,11,11,11,70,00
                    HEX        00,71,11,77,77,11,17,00
                    HEX        00,71,17,70,07,71,17,00
                    HEX        00,71,17,00,00,71,17,00
                    HEX        00,71,17,00,00,71,17,00
                    HEX        00,77,77,00,00,71,17,00
                    HEX        00,00,00,07,77,11,17,00
                    HEX        00,00,00,71,11,11,70,00
                    HEX        00,00,00,71,11,11,17,00
                    HEX        00,00,00,77,77,71,11,70
                    HEX        00,00,00,00,00,77,11,70
                    HEX        00,07,70,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,71,11,70
                    HEX        00,71,11,77,77,11,17,70
                    HEX        00,77,11,11,11,11,77,00
                    HEX        00,07,77,11,11,77,70,00
                    HEX        00,00,07,77,77,70,00,00

Number4             HEX        00,00,00,00,07,77,70,00 ; 4
                    HEX        00,00,00,00,71,11,70,00
                    HEX        00,00,00,07,11,11,70,00
                    HEX        00,00,00,07,11,11,70,00
                    HEX        00,00,00,71,11,11,70,00
                    HEX        00,00,00,71,17,11,70,00
                    HEX        00,00,07,11,17,11,70,00
                    HEX        00,00,07,11,77,11,70,00
                    HEX        00,00,71,11,77,11,70,00
                    HEX        00,00,71,17,77,11,70,00
                    HEX        00,07,11,17,07,11,70,00
                    HEX        00,07,11,77,07,11,70,00
                    HEX        00,71,11,77,77,11,77,70
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,77,77,77,77,11,77,70
                    HEX        00,00,00,00,07,11,70,00
                    HEX        00,00,00,00,07,11,70,00
                    HEX        00,00,00,00,07,11,70,00
                    HEX        00,00,00,00,07,77,70,00

Number5             HEX        00,77,77,77,77,77,70,00 ; 5
                    HEX        00,71,11,11,11,11,17,00
                    HEX        00,71,11,11,11,11,17,00
                    HEX        00,71,17,77,77,77,77,00
                    HEX        00,71,17,00,00,00,00,00
                    HEX        00,71,17,00,00,00,00,00
                    HEX        00,71,17,77,77,00,00,00
                    HEX        00,71,17,11,11,77,00,00
                    HEX        00,71,11,11,11,11,70,00
                    HEX        00,71,11,77,77,11,17,00
                    HEX        00,77,77,00,00,71,11,70
                    HEX        00,00,00,00,00,07,11,70
                    HEX        00,00,00,00,00,07,11,70
                    HEX        00,77,70,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,71,11,70
                    HEX        00,71,11,77,77,11,17,70
                    HEX        00,77,11,11,11,11,77,00
                    HEX        00,07,77,11,11,77,70,00
                    HEX        00,00,07,77,77,70,00,00

Number6             HEX        00,00,00,77,77,70,00,00 ; 6
                    HEX        00,00,77,11,11,17,70,00
                    HEX        00,07,11,11,11,11,17,00
                    HEX        00,71,11,77,77,71,11,70
                    HEX        00,71,17,70,00,77,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,77,70
                    HEX        00,71,17,77,77,00,00,00
                    HEX        00,71,17,11,11,77,00,00
                    HEX        00,71,11,11,11,11,70,00
                    HEX        00,71,11,17,77,11,17,00
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,77,11,17,77,11,17,70
                    HEX        00,07,71,11,11,11,77,00
                    HEX        00,00,77,71,11,77,70,00
                    HEX        00,00,00,77,77,70,00,00

Number7             HEX        00,77,77,77,77,77,77,00 ; 7
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,71,11,11,11,11,11,70
                    HEX        00,77,77,77,77,71,11,70
                    HEX        00,00,00,00,07,11,17,70
                    HEX        00,00,00,00,07,11,77,00
                    HEX        00,00,00,00,71,11,70,00
                    HEX        00,00,00,00,71,17,70,00
                    HEX        00,00,00,07,11,17,00,00
                    HEX        00,00,00,07,11,77,00,00
                    HEX        00,00,00,71,11,70,00,00
                    HEX        00,00,00,71,17,70,00,00
                    HEX        00,00,07,11,17,00,00,00
                    HEX        00,00,07,11,77,00,00,00
                    HEX        00,00,07,11,70,00,00,00
                    HEX        00,00,71,11,70,00,00,00
                    HEX        00,00,71,17,70,00,00,00
                    HEX        00,00,71,17,00,00,00,00
                    HEX        00,00,71,17,00,00,00,00
                    HEX        00,00,77,77,00,00,00,00

Number8             HEX        00,00,00,07,77,00,00,00 ; 8
                    HEX        00,00,07,71,11,77,00,00
                    HEX        00,00,71,11,11,11,70,00
                    HEX        00,07,11,17,77,11,17,00
                    HEX        00,07,11,77,07,71,17,00
                    HEX        00,07,11,70,00,71,17,00
                    HEX        00,07,11,70,00,71,17,00
                    HEX        00,07,11,17,77,11,17,00
                    HEX        00,00,71,11,11,11,70,00
                    HEX        00,00,07,11,11,17,00,00
                    HEX        00,00,71,11,11,11,70,00
                    HEX        00,07,11,17,77,11,17,00
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,77,11,17,77,11,17,70
                    HEX        00,07,71,11,11,11,77,00
                    HEX        00,00,77,71,11,77,70,00
                    HEX        00,00,00,77,77,70,00,00

Number9             HEX        00,00,00,07,77,00,00,00 ; 9
                    HEX        00,00,07,71,11,77,00,00
                    HEX        00,00,71,11,11,11,70,00
                    HEX        00,07,11,17,77,11,17,00
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,17,00,00,07,11,70
                    HEX        00,71,11,70,00,71,11,70
                    HEX        00,77,11,17,77,11,11,70
                    HEX        00,07,71,11,11,11,11,70
                    HEX        00,00,77,71,11,17,11,70
                    HEX        00,00,00,77,77,77,11,70
                    HEX        00,77,70,00,00,07,11,70
                    HEX        00,71,17,00,00,71,11,70
                    HEX        00,71,11,77,77,11,17,70
                    HEX        00,77,11,11,11,11,77,00
                    HEX        00,07,77,11,11,77,70,00
                    HEX        00,00,07,77,77,70,00,00


***********************************************
*  Score/Life Screen :  Your Mission is Over. *
***********************************************

MissionIsOver       ENT                              ; Global Reference
                    HEX        11,10,00,01,11,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,11,00,00,01,10,00,11,10,00,00,00,00,00,00,00,00,00,00,11,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,11,00,00,00,00,00,00,00,00,00,00,11,10,00,00,00,00,00,00,00,00,00,00,00,00,00
                    HEX        12,21,00,12,21,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,12,10,00,12,10,01,22,10,00,00,00,00,00,00,00,00,00,01,22,10,00,00,00,00,00,00,00,00,00,00,00,00,00,01,22,10,00,00,00,00,00,00,00,00,01,22,21,00,00,00,00,00,00,00,00,00,00,00,00,00
                    HEX        12,21,00,12,21,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,12,10,00,12,10,01,22,10,00,00,00,00,00,00,00,00,00,01,22,10,00,00,00,00,00,00,00,00,00,00,00,00,00,01,22,10,00,00,00,00,00,00,00,00,12,21,22,10,00,00,00,00,00,00,00,00,00,00,00,00
                    HEX        12,21,00,12,21,01,11,10,00,11,00,11,01,11,01,10,00,00,00,00,12,21,01,22,10,01,11,10,00,01,11,11,00,01,11,11,00,01,11,10,00,01,11,10,00,11,11,10,00,00,00,00,00,01,11,10,00,01,11,11,00,00,00,01,22,11,12,21,01,10,01,10,00,11,11,00,11,10,11,00
                    HEX        11,22,11,22,11,12,22,21,01,22,11,22,12,22,12,21,00,00,00,00,12,21,01,22,10,12,22,10,00,12,22,22,10,12,22,22,10,12,22,10,00,12,22,21,01,22,22,21,00,00,00,00,00,12,22,10,00,12,22,22,10,00,00,01,22,10,12,21,12,21,12,21,01,22,22,11,22,21,22,10
                    HEX        01,12,22,21,11,22,11,22,11,22,11,22,11,22,21,22,10,00,00,00,12,22,12,22,10,11,22,10,01,22,21,11,11,22,21,11,10,11,22,10,01,22,11,22,11,22,11,22,10,00,00,00,00,11,22,10,01,22,21,11,10,00,00,01,22,10,12,21,12,21,12,21,12,21,12,21,12,22,12,21
                    HEX        00,11,22,11,01,22,11,22,11,22,11,22,11,22,11,22,10,00,00,00,12,22,22,22,10,01,22,10,01,12,22,10,01,12,22,10,00,01,22,10,01,22,11,22,11,22,11,22,10,00,00,00,00,01,22,10,01,12,22,10,00,00,00,01,22,10,12,21,12,21,12,21,12,21,12,21,12,21,12,21
                    HEX        00,01,22,10,01,22,11,22,11,22,11,22,11,22,11,11,10,00,00,00,12,21,21,22,10,01,22,10,00,11,22,21,00,11,22,21,00,01,22,10,01,22,11,22,11,22,11,22,10,00,00,00,00,01,22,10,00,11,22,21,00,00,00,01,22,10,12,21,11,22,22,11,12,22,22,21,12,21,11,11
                    HEX        00,01,22,10,01,22,11,22,11,22,11,22,11,22,10,00,00,00,00,00,12,21,21,22,10,01,22,10,00,11,12,22,10,11,12,22,10,01,22,10,01,22,11,22,11,22,11,22,10,00,00,00,00,01,22,10,00,11,12,22,10,00,00,01,12,21,22,11,01,22,22,10,12,21,11,11,12,21,00,00
                    HEX        00,12,22,21,01,12,22,21,11,12,22,12,22,22,21,00,00,00,00,00,12,21,11,22,10,12,22,21,01,22,22,21,11,22,22,21,10,12,22,21,01,12,22,21,11,22,11,22,10,00,00,00,00,12,22,21,01,22,22,21,10,00,00,00,11,22,21,10,01,12,21,10,11,22,22,11,22,22,10,00
                    HEX        00,11,11,11,00,11,11,11,00,11,11,11,11,11,11,00,00,00,00,00,11,11,01,11,10,11,11,11,01,11,11,11,11,11,11,11,00,11,11,11,00,11,11,11,01,11,11,11,10,00,00,00,00,11,11,11,01,11,11,11,00,00,00,00,01,11,11,00,00,11,11,00,01,11,11,11,11,11,10,00


**************************************************
*  Attract Screen :  Press Fire Button to Start. *
**************************************************

PressFireButton     ENT                             ; Global Reference
                    HEX        01,11,11,11,11,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,11,11,11,11,11,11,11,00,00,00,00,00,00,00,00,00,00,00,00,11,11,11,11,10,00,00,00,00,00,11,10,00,01,11,00,00,00,00,00,00,00,00,00,00,00,00,00,00,11,10,00,00,00,00,00,00,00,00,01,11,11,11,00,11,10,00,00,00,00,00,00,00,00,00,00,01,11,00,00
                    HEX        01,22,22,22,21,10,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,00,12,22,22,22,21,12,21,00,00,00,00,00,00,00,00,00,00,00,00,12,22,22,22,11,00,00,00,00,01,12,10,00,11,21,00,00,00,00,00,00,00,00,00,00,00,00,00,01,12,10,00,00,00,00,00,00,00,00,11,22,22,21,11,12,10,00,00,00,00,00,00,00,00,00,00,11,21,00,00
                    HEX        01,12,21,11,22,11,11,11,11,10,11,11,11,10,11,11,11,11,11,11,11,11,00,00,00,11,22,11,12,21,11,11,11,11,11,11,10,11,11,11,10,00,00,00,11,22,11,12,21,11,10,11,11,11,22,11,11,12,21,11,01,11,11,11,11,11,11,11,00,00,00,00,11,22,11,10,11,11,11,10,00,00,00,12,21,11,22,11,22,11,10,11,11,11,10,11,11,11,11,11,12,21,11,00
                    HEX        00,12,21,11,22,12,22,12,22,11,12,22,22,11,12,22,22,21,12,22,22,21,00,00,00,01,22,11,11,11,22,21,12,22,12,22,11,12,22,22,11,00,00,00,01,22,11,12,21,22,10,12,21,12,22,22,11,22,22,21,11,22,22,21,12,21,22,21,10,00,00,00,12,22,22,11,12,22,22,11,00,00,00,12,22,11,11,12,22,22,10,12,22,22,11,12,22,12,22,11,22,22,21,00
                    HEX        00,12,22,22,21,11,22,21,12,21,22,11,12,21,22,11,11,11,22,11,11,11,00,00,00,01,22,22,21,01,12,21,11,22,21,12,21,22,11,12,21,00,00,00,01,22,22,22,11,22,10,12,21,11,22,11,11,12,21,11,12,21,11,22,12,22,11,22,10,00,00,00,11,22,11,11,22,11,12,21,00,00,00,11,12,22,11,11,22,11,10,11,11,12,21,11,22,21,12,21,12,21,11,00
                    HEX        00,12,21,11,11,01,22,11,12,21,22,22,22,21,12,22,22,11,12,22,22,11,00,00,00,01,22,11,11,00,12,21,01,22,11,12,21,22,22,22,21,00,00,00,01,22,11,12,21,22,10,12,21,01,22,11,11,12,21,11,12,21,01,22,12,21,11,22,10,00,00,00,01,22,11,11,22,10,12,21,00,00,00,11,11,12,22,11,22,11,11,12,22,22,21,01,22,11,12,21,12,21,11,10
                    HEX        01,12,21,11,00,11,22,11,11,11,22,11,11,11,11,11,12,21,11,11,12,21,00,00,00,11,22,11,10,01,12,21,11,22,11,11,11,22,11,11,11,00,00,00,11,22,11,12,21,22,11,12,21,11,22,11,21,12,21,12,12,21,11,22,12,21,01,22,10,00,00,00,01,22,11,21,22,11,12,21,00,00,00,12,21,11,22,11,22,11,21,22,11,12,21,11,22,11,11,11,12,21,12,10
                    HEX        01,22,22,21,00,12,22,21,00,01,12,22,22,11,22,22,22,11,22,22,22,11,00,00,00,12,22,22,10,01,22,22,12,22,21,00,01,12,22,22,10,00,00,00,12,22,22,22,11,12,22,21,22,11,12,22,11,11,22,21,11,22,22,21,12,21,01,22,10,00,00,00,01,12,22,11,12,22,22,11,00,00,00,11,22,22,21,11,12,22,11,12,22,21,22,12,22,21,00,00,11,22,21,10
                    HEX        01,11,11,11,00,11,11,11,00,00,11,11,11,11,11,11,11,11,11,11,11,10,00,00,00,11,11,11,10,01,11,11,11,11,11,00,00,11,11,11,10,00,00,00,11,11,11,11,10,11,11,11,11,10,11,11,10,01,11,11,01,11,11,11,11,11,01,11,10,00,00,00,00,11,11,10,11,11,11,10,00,00,00,01,11,11,11,00,11,11,10,11,11,11,11,11,11,11,00,00,01,11,11,00


********************************
*  Final Score :  Final Score. *
********************************

FinalScore          ENT                             ; Global Reference
                    HEX        07,77,77,77,77,07,77,77,77,77,70,77,77,00,77,77,07,77,77,70,00,00,00,00,00,07,77,77,70,07,77,77,70,07,77,77,07,77,77,77,77,77,77,77,77,00
                    HEX        07,11,11,11,17,07,11,11,77,11,77,71,17,07,71,17,77,11,11,70,00,00,00,00,00,77,11,11,77,77,11,11,77,77,11,17,77,11,11,11,77,11,11,11,17,00
                    HEX        07,71,17,77,17,07,71,17,77,11,17,71,17,77,11,11,77,71,17,70,00,00,00,00,00,71,17,71,17,71,17,71,17,71,17,11,77,71,17,71,17,71,17,77,17,00
                    HEX        00,71,17,17,77,00,71,17,77,11,11,71,17,71,17,71,17,71,17,00,00,00,00,00,00,71,11,77,77,11,77,77,77,11,77,71,17,71,17,71,17,71,17,17,77,00
                    HEX        00,71,11,17,00,00,71,17,07,11,71,11,17,71,17,71,17,71,17,07,77,00,00,00,00,77,11,17,77,11,70,00,07,11,70,71,17,71,11,11,77,71,11,17,00,00
                    HEX        00,71,17,17,00,00,71,17,07,11,77,11,17,71,11,11,17,71,17,77,17,00,00,00,00,77,77,11,17,11,77,77,77,11,77,71,17,71,17,11,77,71,17,17,77,00
                    HEX        07,71,17,77,00,07,71,17,77,11,77,71,17,71,17,71,17,71,17,71,17,00,00,00,00,71,17,71,17,71,17,71,17,71,17,11,77,71,17,71,17,71,17,77,17,00
                    HEX        07,11,11,70,00,07,11,11,77,11,70,71,17,71,17,71,17,11,11,11,17,00,00,00,00,77,11,11,77,77,11,11,77,77,11,17,77,11,17,71,17,11,11,11,17,00
                    HEX        07,77,77,70,00,07,77,77,77,77,70,77,77,77,77,77,77,77,77,77,77,00,00,00,00,07,77,77,70,07,77,77,70,07,77,77,07,77,77,77,77,77,77,77,77,00
 
 
********************************************
*  Alphabet :  A-Z a-z 0-9 Actions Arrows. *
********************************************
 
Alpha_Char          ENT
                    ASC        'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789abcdefghijklmnopqrstuvwxyz ."/[]',00 

Alpha_Tab           ENT
                    DA         Aplha_A,Aplha_B,Aplha_C,Aplha_D,Aplha_E,Aplha_F,Aplha_G,Aplha_H,Aplha_I,Aplha_J
                    DA         Aplha_K,Aplha_L,Aplha_M,Aplha_N,Aplha_O,Aplha_P,Aplha_Q,Aplha_R,Aplha_S,Aplha_T
                    DA         Aplha_U,Aplha_V,Aplha_W,Aplha_X,Aplha_Y,Aplha_Z,Aplha_0,Aplha_1,Aplha_2,Aplha_3
                    DA         Aplha_4,Aplha_5,Aplha_6,Aplha_7,Aplha_8,Aplha_9,Aplha_a,Aplha_b,Aplha_c,Aplha_d
                    DA         Aplha_e,Aplha_f,Aplha_g,Aplha_h,Aplha_i,Aplha_j,Aplha_k,Aplha_l,Aplha_m,Aplha_n
                    DA         Aplha_o,Aplha_p,Aplha_q,Aplha_r,Aplha_s,Aplha_t,Aplha_u,Aplha_v,Aplha_w,Aplha_x
                    DA         Aplha_y,Aplha_z,Aplha_Space,Aplha_Dot,Aplha_Quote,Aplha_Slash,Aplha_OpenBracket,
                    DA         Aplha_CloseBracket
 
Aplha_A             HEX        00,02,22,20,00,00    ; A
                    HEX        00,22,11,22,00,00
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_B             HEX        22,22,22,22,00,00    ; B
                    HEX        21,11,11,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,11,12,20,00
                    HEX        22,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_C             HEX        00,22,22,22,00,00    ; C
                    HEX        02,21,11,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,12,22,22,20,00
                    HEX        21,12,00,00,00,00
                    HEX        21,12,22,22,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_D             HEX        22,22,22,20,00,00    ; D
                    HEX        21,11,11,22,00,00
                    HEX        22,11,21,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        22,11,21,12,20,00
                    HEX        21,11,11,22,00,00
                    HEX        22,22,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_E             HEX        22,22,22,22,20,00    ; E
                    HEX        21,11,11,11,20,00
                    HEX        22,11,22,21,20,00
                    HEX        02,11,21,22,20,00
                    HEX        02,11,11,20,00,00
                    HEX        02,11,21,22,20,00
                    HEX        22,11,22,21,20,00
                    HEX        21,11,11,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_F             HEX        22,22,22,22,20,00    ; F
                    HEX        21,11,11,11,20,00
                    HEX        22,11,22,21,20,00
                    HEX        02,11,21,22,20,00
                    HEX        02,11,11,20,00,00
                    HEX        02,11,21,20,00,00
                    HEX        22,11,22,20,00,00
                    HEX        21,11,12,00,00,00
                    HEX        22,22,22,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_G             HEX        00,22,22,22,00,00    ; G
                    HEX        02,21,11,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,12,22,22,20,00
                    HEX        21,12,22,22,20,00
                    HEX        21,12,21,11,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,21,11,11,20,00
                    HEX        00,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_H             HEX        02,22,22,22,20,00    ; H
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_I             HEX        00,22,22,22,00,00    ; I
                    HEX        00,21,11,12,00,00
                    HEX        00,22,11,22,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,22,11,22,00,00
                    HEX        00,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_J             HEX        00,02,22,22,20,00    ; J
                    HEX        00,02,11,11,20,00
                    HEX        00,02,21,12,20,00
                    HEX        00,00,21,12,00,00
                    HEX        22,22,21,12,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,12,21,12,00,00
                    HEX        22,11,11,22,00,00
                    HEX        02,22,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_K             HEX        22,22,22,22,20,00    ; K
                    HEX        21,11,22,11,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,11,21,12,20,00
                    HEX        02,11,11,22,00,00
                    HEX        02,11,21,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,22,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_L             HEX        22,22,22,00,00,00    ; L
                    HEX        21,11,12,00,00,00
                    HEX        22,11,22,00,00,00
                    HEX        02,11,20,00,00,00
                    HEX        02,11,20,22,20,00
                    HEX        02,11,22,21,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_M             HEX        22,22,02,22,20,00    ; M
                    HEX        21,12,22,11,20,00
                    HEX        21,11,21,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        21,12,12,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,02,11,20,00
                    HEX        22,22,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_N             HEX        22,22,02,22,20,00    ; N
                    HEX        21,12,22,11,20,00
                    HEX        21,11,22,11,20,00
                    HEX        21,11,12,11,20,00
                    HEX        21,12,11,11,20,00
                    HEX        21,12,21,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,02,11,20,00
                    HEX        22,22,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_O             HEX        00,22,22,20,00,00    ; O
                    HEX        02,21,11,22,00,00
                    HEX        22,11,21,12,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,02,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,11,21,12,20,00
                    HEX        02,21,11,22,00,00
                    HEX        00,22,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_P             HEX        22,22,22,22,00,00    ; P
                    HEX        21,11,11,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,22,22,00,00
                    HEX        22,11,22,00,00,00
                    HEX        21,11,12,00,00,00
                    HEX        22,22,22,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_Q             HEX        00,22,22,22,00,00    ; Q
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,21,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,21,11,20,00
                    HEX        00,00,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_R             HEX        22,22,22,22,00,00    ; R
                    HEX        21,11,11,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,21,12,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,22,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_S             HEX        00,22,22,22,00,00    ; S
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,12,22,20,00
                    HEX        02,21,11,22,20,00
                    HEX        02,22,21,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_T             HEX        02,22,22,22,20,00    ; T
                    HEX        02,11,11,11,20,00
                    HEX        02,12,11,21,20,00
                    HEX        02,22,11,22,20,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,22,11,22,00,00
                    HEX        00,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_U             HEX        02,22,22,22,20,00    ; U
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_V             HEX        02,22,22,22,20,00    ; V
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,11,22,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_W             HEX        22,22,02,22,20,00    ; W
                    HEX        21,12,02,11,20,00
                    HEX        21,12,02,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,12,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        21,11,21,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,22,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_X             HEX        22,22,02,22,20,00    ; X
                    HEX        21,12,02,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,11,21,12,20,00
                    HEX        02,21,11,22,00,00
                    HEX        02,21,11,22,00,00
                    HEX        22,11,21,12,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,22,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_Y             HEX        02,22,22,22,20,00    ; Y
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,11,22,00,00
                    HEX        00,22,11,22,00,00
                    HEX        00,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_Z             HEX        22,22,22,22,20,00    ; Z
                    HEX        21,11,11,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,22,21,12,20,00
                    HEX        22,22,11,22,20,00
                    HEX        02,21,12,21,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_0             HEX        02,22,22,22,00,00    ; 0
                    HEX        22,11,11,12,20,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,21,11,20,00
                    HEX        21,12,11,11,20,00
                    HEX        21,11,12,11,20,00
                    HEX        21,11,22,11,20,00
                    HEX        22,11,11,12,20,00
                    HEX        02,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_1             HEX        00,02,22,20,00,00    ; 1
                    HEX        00,22,11,20,00,00
                    HEX        00,21,11,20,00,00
                    HEX        00,22,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        02,22,11,22,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_2             HEX        00,22,22,22,00,00    ; 2
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,11,20,00
                    HEX        00,22,11,12,20,00
                    HEX        02,21,12,22,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_3             HEX        00,22,22,22,00,00    ; 3
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,11,20,00
                    HEX        00,02,11,12,20,00
                    HEX        02,22,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_4             HEX        00,02,22,22,00,00    ; 4
                    HEX        00,22,11,12,00,00
                    HEX        02,21,11,12,00,00
                    HEX        22,11,21,12,00,00
                    HEX        21,12,21,12,20,00
                    HEX        21,11,11,11,20,00
                    HEX        22,22,21,12,20,00
                    HEX        00,02,11,11,20,00
                    HEX        00,02,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_5             HEX        02,22,22,22,20,00    ; 5
                    HEX        02,11,11,11,20,00
                    HEX        02,11,22,22,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,22,22,11,20,00
                    HEX        02,22,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_6             HEX        00,02,22,22,00,00    ; 6
                    HEX        00,22,11,12,00,00
                    HEX        02,21,12,22,00,00
                    HEX        02,11,22,22,00,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_7             HEX        02,22,22,22,20,00    ; 7
                    HEX        02,11,11,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,11,20,00
                    HEX        00,02,21,12,20,00
                    HEX        00,02,11,22,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_8             HEX        00,22,22,22,00,00    ; 8
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_9             HEX        00,22,22,22,00,00    ; 9
                    HEX        02,21,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,11,20,00
                    HEX        00,22,22,11,20,00
                    HEX        00,22,22,12,20,00
                    HEX        00,21,11,22,00,00
                    HEX        00,22,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_a             HEX        00,00,00,00,00,00    ; a
                    HEX        00,00,00,00,00,00
                    HEX        00,22,22,00,00,00
                    HEX        02,11,11,20,00,00
                    HEX        00,22,21,12,00,00
                    HEX        02,11,11,12,00,00
                    HEX        21,12,21,12,20,00
                    HEX        22,11,12,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_b             HEX        02,22,00,00,00,00    ; b
                    HEX        21,11,20,00,00,00
                    HEX        02,11,20,00,00,00
                    HEX        02,11,22,22,00,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        21,12,11,12,20,00
                    HEX        22,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_c             HEX        00,00,00,00,00,00    ; c
                    HEX        00,00,00,00,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,21,11,12,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,22,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_d             HEX        00,00,22,20,00,00    ; d
                    HEX        00,02,11,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,22,21,12,00,00
                    HEX        02,11,11,12,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,12,21,12,20,00
                    HEX        22,11,12,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_e             HEX        00,00,00,00,00,00    ; e
                    HEX        00,00,00,00,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,21,11,12,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,11,22,22,20,00
                    HEX        02,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_f             HEX        00,00,22,20,00,00    ; f
                    HEX        00,02,11,12,00,00
                    HEX        00,21,12,11,20,00
                    HEX        00,21,12,22,20,00
                    HEX        02,11,11,20,00,00
                    HEX        02,21,12,20,00,00
                    HEX        02,21,12,20,00,00
                    HEX        02,11,11,20,00,00
                    HEX        02,22,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_g             HEX        00,00,00,00,00,00    ; g
                    HEX        00,00,00,00,00,00
                    HEX        00,22,20,22,00,00
                    HEX        02,11,12,11,20,00
                    HEX        21,12,21,12,20,00
                    HEX        21,12,21,12,00,00
                    HEX        02,11,11,12,00,00
                    HEX        02,22,21,12,00,00
                    HEX        21,11,11,22,00,00
                    HEX        22,22,22,20,00,00

Aplha_h             HEX        02,22,00,00,00,00    ; h
                    HEX        21,11,20,00,00,00
                    HEX        02,11,22,20,00,00
                    HEX        02,11,21,12,00,00
                    HEX        02,11,12,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        22,11,22,11,20,00
                    HEX        21,11,22,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_i             HEX        00,00,22,00,00,00    ; i
                    HEX        00,02,11,20,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,21,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,22,00,00
                    HEX        00,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_j             HEX        00,00,00,22,00,00    ; j
                    HEX        00,00,02,11,20,00
                    HEX        00,00,00,22,20,00
                    HEX        00,00,02,11,20,00
                    HEX        00,00,02,11,20,00
                    HEX        00,22,02,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00

Aplha_k             HEX        02,22,00,00,00,00    ; k
                    HEX        21,11,20,00,00,00
                    HEX        02,11,20,22,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,21,12,00,00
                    HEX        02,11,11,22,00,00
                    HEX        22,11,21,12,20,00
                    HEX        21,11,22,11,20,00
                    HEX        22,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_l             HEX        00,02,22,00,00,00    ; l
                    HEX        00,21,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,22,11,20,00,00
                    HEX        00,21,11,12,00,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_m             HEX        00,00,00,00,00,00    ; m
                    HEX        00,00,00,00,00,00
                    HEX        02,20,02,20,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,11,11,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        21,12,12,11,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,22,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_n             HEX        00,00,00,00,00,00    ; n
                    HEX        00,00,00,00,00,00
                    HEX        00,22,22,20,00,00
                    HEX        02,11,11,12,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_o             HEX        00,00,00,00,00,00    ; o
                    HEX        00,00,00,00,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,21,11,12,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_p             HEX        00,00,00,00,00,00    ; p
                    HEX        00,00,00,00,00,00
                    HEX        02,20,22,20,00,00
                    HEX        21,12,11,12,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,11,22,22,00,00
                    HEX        21,11,12,00,00,00
                    HEX        22,22,22,00,00,00

Aplha_q             HEX        00,00,00,00,00,00    ; q
                    HEX        00,00,00,00,00,00
                    HEX        00,22,20,22,00,00
                    HEX        02,11,12,11,20,00
                    HEX        21,12,21,12,20,00
                    HEX        21,12,21,12,00,00
                    HEX        22,11,11,12,00,00
                    HEX        02,22,21,12,20,00
                    HEX        00,02,11,11,20,00
                    HEX        00,02,22,22,20,00

Aplha_r             HEX        00,00,00,00,00,00    ; r
                    HEX        00,00,00,00,00,00
                    HEX        02,20,22,20,00,00
                    HEX        21,12,11,12,00,00
                    HEX        02,11,12,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,22,20,00
                    HEX        21,11,12,00,00,00
                    HEX        22,22,22,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_s             HEX        00,00,00,00,00,00    ; s
                    HEX        00,00,00,00,00,00
                    HEX        00,02,22,22,00,00
                    HEX        00,21,11,11,20,00
                    HEX        02,11,22,22,00,00
                    HEX        00,21,11,12,20,00
                    HEX        00,02,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_t             HEX        00,00,20,00,00,00    ; t
                    HEX        00,02,12,00,00,00
                    HEX        00,21,12,00,00,00
                    HEX        02,11,11,12,00,00
                    HEX        02,21,12,22,00,00
                    HEX        00,21,12,22,00,00
                    HEX        00,21,12,12,00,00
                    HEX        00,22,11,22,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_u             HEX        00,00,00,00,00,00    ; u
                    HEX        00,00,00,00,00,00
                    HEX        02,20,02,20,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,12,21,12,00,00
                    HEX        21,12,21,12,20,00
                    HEX        22,11,12,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_v             HEX        00,00,00,00,00,00    ; v
                    HEX        00,00,00,00,00,00
                    HEX        00,22,00,22,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,12,20,00
                    HEX        00,22,11,22,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_w             HEX        00,00,00,00,00,00    ; w
                    HEX        00,00,00,00,00,00
                    HEX        02,20,00,22,00,00
                    HEX        21,12,22,11,20,00
                    HEX        21,12,12,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        21,11,11,11,20,00
                    HEX        22,11,21,12,20,00
                    HEX        02,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_x             HEX        00,00,00,00,00,00    ; x
                    HEX        00,00,00,00,00,00
                    HEX        02,20,00,22,00,00
                    HEX        21,12,22,11,20,00
                    HEX        22,11,21,12,20,00
                    HEX        02,21,11,22,00,00
                    HEX        02,11,21,12,20,00
                    HEX        21,12,22,11,20,00
                    HEX        22,20,00,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_y             HEX        00,00,00,00,00,00    ; y
                    HEX        00,00,00,00,00,00
                    HEX        00,22,00,22,00,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,11,22,11,20,00
                    HEX        02,21,11,11,20,00
                    HEX        00,22,22,11,20,00
                    HEX        02,11,11,12,20,00
                    HEX        02,22,22,22,00,00

Aplha_z             HEX        00,00,00,00,00,00    ; z
                    HEX        00,00,00,00,00,00
                    HEX        00,22,22,22,00,00
                    HEX        02,11,11,11,20,00
                    HEX        02,12,21,12,00,00
                    HEX        02,22,11,22,20,00
                    HEX        00,21,12,21,20,00
                    HEX        02,11,11,11,20,00
                    HEX        02,22,22,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_Space         HEX        00,00,00,00,00,00    ; Space
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_Dot           HEX        00,00,00,00,00,00    ; .
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,22,00,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_Quote         HEX        00,00,00,00,00,00    ; '
                    HEX        00,02,22,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    
Aplha_Slash         HEX        00,00,02,22,20,00    ; /
                    HEX        00,00,02,11,20,00
                    HEX        00,00,02,11,20,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,02,11,20,00,00
                    HEX        00,21,12,00,00,00
                    HEX        00,22,22,00,00,00
                    HEX        00,00,00,00,00,00
                    
Aplha_OpenBracket   HEX        00,22,22,22,20,00    ; [
                    HEX        00,21,11,11,20,00
                    HEX        00,21,12,22,20,00
                    HEX        00,21,12,00,00,00
                    HEX        00,21,12,00,00,00
                    HEX        00,21,12,00,00,00
                    HEX        00,21,12,22,20,00
                    HEX        00,21,11,11,20,00
                    HEX        00,22,22,22,20,00
                    HEX        00,00,00,00,00,00
                    
Aplha_CloseBracket  HEX        02,22,22,22,00,00    ; ]
                    HEX        02,11,11,12,00,00
                    HEX        02,22,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        02,22,21,12,00,00
                    HEX        02,11,11,12,00,00
                    HEX        02,22,22,22,00,00
                    HEX        00,00,00,00,00,00

Aplha_Action        ENT
                    HEX        22,22,22,22,22,22    ; Action [-]
                    HEX        21,11,11,11,11,12
                    HEX        21,11,11,11,11,12
                    HEX        21,12,22,22,21,12
                    HEX        21,12,22,22,21,12
                    HEX        22,22,21,12,22,22
                    HEX        22,22,21,12,22,22
                    HEX        21,12,22,22,21,12
                    HEX        21,12,22,22,21,12
                    HEX        21,11,11,11,11,12
                    HEX        21,11,11,11,11,12
                    HEX        22,22,22,22,22,22

Aplha_Action_Mask   HEX        00,00,00,00,00,00    ; Action [-]
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_Event         ENT
                    HEX        00,00,00,00,00,00    ; Event []
                    HEX        02,22,22,22,22,20
                    HEX        02,11,21,11,11,20
                    HEX        02,11,21,11,11,20
                    HEX        02,11,22,22,22,20
                    HEX        02,11,20,02,11,20
                    HEX        02,11,20,02,11,20
                    HEX        02,22,22,22,11,20
                    HEX        02,11,11,12,11,20
                    HEX        02,11,11,12,11,20
                    HEX        02,22,22,22,22,20
                    HEX        00,00,00,00,00,00

Aplha_Event_Mask    HEX        FF,FF,FF,FF,FF,FF    ; Event []
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,0F,F0,00,0F
                    HEX        F0,00,0F,F0,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        FF,FF,FF,FF,FF,FF

Aplha_Up            ENT
                    HEX        00,00,22,22,00,00    ; ^
                    HEX        00,02,21,12,20,00
                    HEX        00,22,11,11,22,00
                    HEX        02,21,11,11,12,20
                    HEX        02,11,21,12,11,20
                    HEX        02,12,21,12,21,20
                    HEX        02,22,21,12,22,20
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,22,22,00,00

Aplha_Up_Mask       HEX        FF,FF,00,00,FF,FF    ; ^
                    HEX        FF,F0,00,00,0F,FF
                    HEX        FF,00,00,00,00,FF
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF

Aplha_Down          ENT
                    HEX        00,00,22,22,00,00    ; v
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        00,00,21,12,00,00
                    HEX        02,22,21,12,22,20
                    HEX        02,12,21,12,21,20
                    HEX        02,11,21,12,11,20
                    HEX        02,21,11,11,12,20
                    HEX        00,22,11,11,22,00
                    HEX        00,02,21,12,20,00
                    HEX        00,00,22,22,00,00

Aplha_Down_Mask     HEX        FF,FF,00,00,FF,FF    ; v
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        FF,FF,00,00,FF,FF
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        F0,00,00,00,00,0F
                    HEX        FF,00,00,00,00,FF
                    HEX        FF,F0,00,00,0F,FF
                    HEX        FF,FF,00,00,FF,FF

Aplha_Left          ENT
                    HEX        00,00,00,00,00,00    ; <-
                    HEX        00,02,22,20,00,00
                    HEX        00,22,11,20,00,00
                    HEX        02,21,12,20,00,00
                    HEX        22,11,22,22,22,22
                    HEX        21,11,11,11,11,12
                    HEX        21,11,11,11,11,12
                    HEX        22,11,22,22,22,22
                    HEX        02,21,12,20,00,00
                    HEX        00,22,11,20,00,00
                    HEX        00,02,22,20,00,00
                    HEX        00,00,00,00,00,00

Aplha_Left_Mask     HEX        FF,FF,FF,FF,FF,FF    ; <-
                    HEX        FF,F0,00,0F,FF,FF
                    HEX        FF,00,00,0F,FF,FF
                    HEX        F0,00,00,0F,FF,FF
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        F0,00,00,0F,FF,FF
                    HEX        FF,00,00,0F,FF,FF
                    HEX        FF,F0,00,0F,FF,FF
                    HEX        FF,FF,FF,FF,FF,FF

Aplha_Right         ENT
                    HEX        00,00,00,00,00,00    ; ->
                    HEX        00,00,02,22,20,00
                    HEX        00,00,02,11,22,00
                    HEX        00,00,02,21,12,20
                    HEX        22,22,22,22,11,22
                    HEX        21,11,11,11,11,12
                    HEX        21,11,11,11,11,12
                    HEX        22,22,22,22,11,22
                    HEX        00,00,02,21,12,20
                    HEX        00,00,02,11,22,00
                    HEX        00,00,02,22,20,00
                    HEX        00,00,00,00,00,00

Aplha_Right_Mask    HEX        FF,FF,FF,FF,FF,FF    ; ->
                    HEX        FF,FF,F0,00,0F,FF
                    HEX        FF,FF,F0,00,00,FF
                    HEX        FF,FF,F0,00,00,0F
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        FF,FF,F0,00,00,0F
                    HEX        FF,FF,F0,00,00,FF
                    HEX        FF,FF,F0,00,0F,FF
                    HEX        FF,FF,FF,FF,FF,FF

Aplha_Bullet        ENT
                    HEX        00,00,00,00,00,00    ; o
                    HEX        00,00,00,00,00,00
                    HEX        00,00,22,22,00,00
                    HEX        00,02,33,33,20,00
                    HEX        00,23,33,33,32,00
                    HEX        00,23,33,33,32,00
                    HEX        00,23,33,33,32,00
                    HEX        00,23,33,33,32,00
                    HEX        00,02,33,33,20,00
                    HEX        00,00,22,22,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00

Aplha_Diskette      ENT
                    HEX        02,22,22,22,22,00    ; Diskette
                    HEX        21,12,22,21,21,20
                    HEX        21,12,22,21,21,12
                    HEX        21,12,22,22,21,12
                    HEX        21,11,11,11,11,12
                    HEX        21,11,11,11,11,12
                    HEX        21,22,22,22,22,12
                    HEX        21,21,11,11,12,12
                    HEX        21,21,11,11,12,12
                    HEX        21,21,11,11,12,12
                    HEX        21,21,11,11,12,12
                    HEX        02,22,22,22,22,20

Aplha_Diskette_Mask HEX        F0,00,00,00,00,FF    ; Diskette Mask
                    HEX        00,00,00,00,00,0F
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        00,00,00,00,00,00
                    HEX        F0,00,00,00,00,0F
                    
************************************************
*  Black & White colors in Background Screens. *
************************************************

ColorSceneTab       HEX        0100,0200,0300,0400,0500,0600,0700,0800  ; Scene ID
                    HEX        0900,0901,0A00,0A01,0B00,0C00,0D00,0E00
                    HEX        0F00,1000,1100,1200,1300,1400,1500,1600
                    HEX        1700,1800,1900,1901,1A00,1B00,1C00,1D00
                    HEX        1E00,1F00,2000,2001,2002,2100,2200,2300
                    HEX        2301,2400,2401,2500,2600,2601,2700,2701
                    HEX        2800,0000     

ColorBWTab          HEX        8800,4400,2211,1100,1122,1144,2211,5544  ; W B  
                    HEX        3311,3311,2211,1144,4422,2244,1122,3322
                    HEX        3322,2211,1122,2244,6622,6644,5511,5544
                    HEX        5544,3322,3322,1144,2244,7744,6622,2211
                    HEX        1122,5511,2211,6644,FF22,6644,6622,5511
                    HEX        6622,5511,3311,2266,6644,FF22,4411,4433
                    HEX        1122
                
********************************************************************************
